@@ -119,8 +119,8 @@ class Joint:
             "namespace": "",
         },
     )
-    pose: "Joint.Pose" = field(
-        default="0 0 0 0 0 0",
+    pose: Optional["Joint.Pose"] = field(
+        default=None,
         metadata={
             "type": "Element",
             "namespace": "",
@@ -753,8 +753,8 @@ class Joint:
             defined inside the parent that this frame is attached to.
         """
 
-        pose: "Joint.Frame.Pose" = field(
-            default="0 0 0 0 0 0",
+        pose: Optional["Joint.Frame.Pose"] = field(
+            default=None,
             metadata={
                 "type": "Element",
                 "namespace": "",
@@ -779,7 +779,7 @@ class Joint:
             """
 
             value: str = field(
-                default="",
+                default="0 0 0 0 0 0",
                 metadata={
                     "required": True,
                     "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
@@ -802,7 +802,7 @@ class Joint:
         """
 
         value: str = field(
-            default="",
+            default="0 0 0 0 0 0",
             metadata={
                 "required": True,
                 "pattern": r"(\s*(-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+)\s+){5}((-|\+)?(\d+(\.\d*)?|\.\d+|\d+\.\d+[eE][-\+]?[0-9]+))\s*",
